@@ -1,5 +1,6 @@
 """VideoBGRemover Python SDK - Remove video backgrounds with AI and compose videos with FFmpeg."""
 
+from .__version__ import __version__
 from .client import VideoBGRemoverClient
 from .media import (
     Video,
@@ -9,6 +10,7 @@ from .media import (
     EncoderProfile,
     RemoveBGOptions,
     Prefer,
+    Model,
     MediaContext,
     default_context,
     set_default_context,
@@ -16,14 +18,13 @@ from .media import (
 from .core import (
     BackgroundType,
     TransparentFormat,
-    ModelSize,
     Anchor,
     SizeMode,
 )
 
-__version__ = "0.1.0"
 
 __all__ = [
+    "__version__",
     "VideoBGRemoverClient",
     "Video",
     "Background",
@@ -32,12 +33,12 @@ __all__ = [
     "EncoderProfile",
     "RemoveBGOptions",
     "Prefer",
+    "Model",
     "MediaContext",
     "default_context",
     "set_default_context",
     "BackgroundType",
     "TransparentFormat",
-    "ModelSize",
     "Anchor",
     "SizeMode",
 ]
