@@ -4,7 +4,6 @@ from .types import (
     ProgressCb,
     BackgroundType,
     TransparentFormat,
-    ModelSize,
     Anchor,
     SizeMode,
 )
@@ -13,7 +12,6 @@ __all__ = [
     "ProgressCb",
     "BackgroundType",
     "TransparentFormat",
-    "ModelSize",
     "Anchor",
     "SizeMode",
 ]
