@@ -5,7 +5,7 @@ from .backgrounds import Background
 from .foregrounds import Foreground
 from .composition import Composition, LayerHandle
 from .encoders import EncoderProfile
-from .remove_bg import RemoveBGOptions, Prefer
+from .remove_bg import RemoveBGOptions, Prefer, Model
 from .context import MediaContext, default_context, set_default_context
 
 __all__ = [
@@ -17,6 +17,7 @@ __all__ = [
     "EncoderProfile",
     "RemoveBGOptions",
     "Prefer",
+    "Model",
     "MediaContext",
     "default_context",
     "set_default_context",
