@@ -2,7 +2,6 @@
 
 from enum import Enum
 from pydantic import BaseModel
-from ..core.types import ModelSize
 
 
 class Prefer(str, Enum):
@@ -22,9 +21,15 @@ class Prefer(str, Enum):
     STACKED = "stacked_video"  # Deprecated: use STACKED_VIDEO
 
 
+class Model(str, Enum):
+    """AI model for background removal."""
+
+    VIDEOBGREMOVER_ORIGINAL = "videobgremover-original"
+    VIDEOBGREMOVER_LIGHT = "videobgremover-light"
+
+
 class RemoveBGOptions(BaseModel):
     """Options for background removal processing."""
 
     prefer: Prefer = Prefer.AUTO
-    model_size: ModelSize = ModelSize.LARGE
-    use_tensorrt: bool = True
+    model: str | None = None
